
%% Monetary Policy Identification for Norway

clear all
clc

addpath('auxiliary')

%% Choose which figures to run

% Set to 1 to run specific figures
run_main_IRFs              = 1; % Figures 2-3, A7-A11
run_descriptive_figures    = 1; % Figures 1, A2-A4, B1

%% Settings

% Restrict estimation sample for IRFs
start_year          = 1994;
start_month         = 1;
start_quarter       = 1;
end_year            = 2018;
end_month           = 12;
end_quarter         = 4;

% Restrict estimation sample for MP Rule/MP-Surprises
start_year_MP       = 1994;
start_month_MP      = 1;
end_year_MP         = 2018;
end_month_MP        = 12;

% Load shocks directly
load_shocks_directly = 1; % Setting this to zero requires forecast data from Consensus Economics

% Norges Bank Forecasts
include_NB          = 2;
    %-1:   Exclude NB forecasts
    % 0:   Same day forecast
    % 1:   Same month forecast (before announcement)
    % 2-5: Previous month (2) up to four months ago (5) forecast

% Add Consensus Forecasts to Norges Bank Forecasts (annual or quarterly)
include_consensus   = 2;
    % 0:   Do not include
    % 1:   Same month forecast (before announcement)
    % 2-4: Previous month up to three months ago forecast

% Local Projections %
regressor_rate_change       = 0; % Use regressor rate change instead of shocks
                      
% Number of Lags in LP (for shocks and one-period growth of dep.var.)
lags_month_shock            = 36;
lags_month_var              = 0;
lags_quart_shock            = 12;
lags_quart_var              = 0;
lags_annual_shock           = 3;
lags_annual_var             = 0;

% Impulse Response Horizons
IRF_T_month                 = 61;
IRF_T_quart                 = 21;
IRF_T_annual                = 6;

%% Load Data

cd '..\Data\MP Decisions'

% MP Decisions %

date_MP                 = xlsread('MP_decisions.xlsx','Monetary Policy Decisions','A5:C195');
rate_MP                 = xlsread('MP_decisions.xlsx','Monetary Policy Decisions','E5:E195');

if load_shocks_directly == 0

    cd '..\Forecasts'

    % Forecasts %

    % Norges Bank Forecasts
    date_NB                 = xlsread('Norges_Bank_forecasts.xlsx','Annual','B6:D93');
    forecasts_NB            = xlsread('Norges_Bank_forecasts.xlsx','Annual','F6:P93');
    % Consensus Forecasts
    date_CON                = xlsread('Consensus_Forecasts.xlsx','Annual','B6:D350');
    forecasts_CON           = xlsread('Consensus_Forecasts.xlsx','Annual','F6:J350');

end

cd '..\Macro Data'

% Macro Data %

% Annual
date_MA_annual          = xlsread('Macro Data.xls','Annual','A3:A31');
macro_data_annual       = xlsread('Macro Data.xls','Annual','B3:T31');
% Quarterly
date_MA_quart           = xlsread('Macro Data.xls','Quarterly','A3:B118');
macro_data_quart        = xlsread('Macro Data.xls','Quarterly','C3:O118');
% Monthly
date_MA_month           = xlsread('Macro Data.xls','Monthly','A3:B350');
macro_data_month        = xlsread('Macro Data.xls','Monthly','C3:J350');
production_extraction   = xlsread('Macro Data.xls','Monthly','K3:K350');
% Import-weighted exchange rate
exchange_rate_MP        = xlsread('Exchange_Rate_NB.xlsx','ForEx around MP dates','H5:H195')/100;

%% Labels and Variable Indicators

labels_annual     = {'Policy Rate','Unemployment Rate','GDP','Consumer Price Index','Wages and Salaries','Consumption Expenditures', ...
                     'GDP Deflator','Industrial Production','Manufacturing Production','Gross Fixed Capital Form.','House Price Index','Hours Worked',...
                     'Household Income','Top 10\% Income Share','Income Distribution: Gini Coefficient','Income Distribution: P90/P10'};
y_labels_annual     = [1 1 0 0 0 0 0 0 0 0 0 0 0 1 1 1];
ind_PR_annual       = 1;
ind_UN_annual       = 2;
ind_CPIAEL_annual   = 4;
ind_W_annual        = 5;
ind_C_annual        = 6;
ind_DEFL_annual     = 7;
ind_IP_annual       = 8;
ind_MFP_annual      = 9;
ind_HP_annual       = 11;
ind_ineq1_annual    = 14;
ind_ineq2_annual    = 15;
ind_ineq3_annual    = 16;
ind_PPI_annual      = 17;

labels_quart      = {'Policy Rate','Unemployment Rate','GDP','Consumer Price Index','Wages and Salaries','Consumption Expenditures',...
                     'GDP Deflator','Industrial Production','Manufacturing Production','Gross Fixed Capital Form.','House Price Index','Hours Worked'};
y_labels_quart      = [1 1 0 0 0 0 0 0 0 0 0 0];
ind_PR_quart        = 1;
ind_UN_quart        = 2;
ind_CPIAEL_quart    = 4;
ind_W_quart         = 5;
ind_C_quart         = 6;
ind_DEFL_quart      = 7;
ind_IP_quart        = 8;
ind_MFP_quart       = 9;
ind_GFCF_quart      = 10;
ind_HP_quart        = 11;
ind_PPI_quart       = 13;

labels_month        = {'Policy Rate','Unemployment Rate','Consumer Price Index','Industrial Production',...
                       'Manuf. Production','Producer Prices Manuf.','Exchange Rate Kroner/\$','Stock Prices'};
labels_month_sign   = {'All Meetings','Monetary Tightenings','Monetary Easings'};
y_labels_month      = [1 1 0 0 0 0 0 0];
ind_PR_month        = 1;
ind_UN_month        = 2;
ind_CPIAEL_month    = 3;
ind_IP_month        = 4;
ind_MFP_month       = 5;
ind_PPI_month       = 6;
ind_SP_month        = 8;

%% Real Units, IP Dummy, Combining Rates, Rate Changes, Eliminate Outliers

% Convert Nominal Wages, Stock Prices, and House Prices to Real Units
macro_data_month(:,ind_SP_month)    = 100*macro_data_month(:,ind_SP_month)./macro_data_month(:,ind_CPIAEL_month);          % Stock Prices adj. CPI
macro_data_quart(:,ind_HP_quart)    = 100*macro_data_quart(:,ind_HP_quart)./macro_data_quart(:,ind_CPIAEL_quart);          % House Prices adj. CPI
macro_data_quart(:,ind_W_quart)     = 100*macro_data_quart(:,ind_W_quart)./macro_data_quart(:,ind_CPIAEL_quart);           % Wages adj. CPI
macro_data_annual(:,ind_HP_annual)  = 100*macro_data_annual(:,ind_HP_annual)./macro_data_annual(:,ind_CPIAEL_annual);      % House Prices adj. CPI
macro_data_annual(:,ind_W_annual)   = 100*macro_data_annual(:,ind_W_annual)./macro_data_annual(:,ind_CPIAEL_annual);       % Wages adj. CPI

% Account for structural break in industrial production
XX_chow_month           = (1:1:size(macro_data_month,1))';
y_chow_month            = log(macro_data_month(:,ind_IP_month));
burnin_chow_month       = 10;
breakpoints_chow_month  = (burnin_chow_month+1:1:(size(macro_data_month,1)-burnin_chow_month))';
[h_chow_month,p_chow_month,stat_chow_month]     = chowtest(XX_chow_month,y_chow_month,breakpoints_chow_month,'Intercept',false,'Display','off');
[max_stat_chow_month, max_stat_chow_month_pos]  = max(stat_chow_month);
stbreak_IP_date_month                           = breakpoints_chow_month(max_stat_chow_month_pos)+burnin_chow_month;
dummy_IP_month  = date_MA_month(:,1)    < date_MA_month(stbreak_IP_date_month,1) | ( date_MA_month(:,1) == date_MA_month(stbreak_IP_date_month,1) & date_MA_month(:,2) <= date_MA_month(stbreak_IP_date_month,2) );
dummy_IP_quart  = date_MA_quart(:,1)    < date_MA_month(stbreak_IP_date_month,1) | ( date_MA_quart(:,1) == date_MA_month(stbreak_IP_date_month,1) & date_MA_quart(:,2) <= ceil(date_MA_month(stbreak_IP_date_month,2)/3) );
dummy_IP_annual = date_MA_annual(:,1)   <= date_MA_month(stbreak_IP_date_month,1);

% Combine multiple meetings within one month
rate_MP_new             = rate_MP(1,:);
date_MP_new             = date_MP(1,:);
exchange_rate_MP_new    = exchange_rate_MP(1,:);
for jj = 2:size(date_MP,1)
    if date_MP(jj,1)==date_MP(jj-1,1) && date_MP(jj,3)==date_MP(jj-1,3)
        date_MP_new(end,:)          = date_MP(jj,:);
        rate_MP_new(end,:)          = rate_MP(jj,:);
        exchange_rate_MP_new(end,:) = exchange_rate_MP(jj,:);
    else
        date_MP_new             = [date_MP_new;date_MP(jj,:)];
        rate_MP_new             = [rate_MP_new;rate_MP(jj,:)];
        exchange_rate_MP_new    = [exchange_rate_MP_new;exchange_rate_MP(jj,:)];
    end
end
date_MP             = date_MP_new;
rate_MP             = rate_MP_new;
exchange_rate_MP    = exchange_rate_MP_new;

% Create Rate Changes
rate_change_MP          = NaN(size(date_MP,1),1);
for jj = 2:size(rate_change_MP,1)
    rate_change_MP(jj,1)       = rate_MP(jj,1)-rate_MP(jj-1,1);
end

% Eliminate specific meetings (1998 and 2008)
for jj = 1:size(date_MP,1)
    if date_MP(jj,1) == 8 && date_MP(jj,3) == 1998
        rate_change_MP(jj,1) = NaN;
    end
    if date_MP(jj,3) == 2008 && (date_MP(jj,1) == 10 || date_MP(jj,1) == 12)
        rate_change_MP(jj,1) = NaN;
    end
end

%% Construct Forecast Changes and Select Chosen Forecasts

if load_shocks_directly == 0

% Adapt Consensus forecasts
forecasts_CON  = [NaN(size(forecasts_CON,1),1) forecasts_CON(:,1:2) NaN(size(forecasts_CON,1),4) forecasts_CON(:,4:5) NaN(size(forecasts_CON,1),2)];

% Construct NB forecast changes
forecasts_NB_change = NaN(size(forecasts_NB,1),size(forecasts_NB,2));
for kk = 2:size(forecasts_NB,1)
    if date_NB(kk,3) == date_NB(kk-1,3)
        forecasts_NB_change(kk,:)       = forecasts_NB(kk,:)-forecasts_NB(kk-1,:);
    elseif date_NB(kk,3)-1 == date_NB(kk-1,3)
        forecasts_NB_change(kk,1:end-1) = forecasts_NB(kk,1:end-1)-forecasts_NB(kk-1,2:end);
    end
end

% Construct Consensus forecast changes
forecast_lag_CON     = 2; % Choose lag to compute forecast change for Consensus
forecasts_CON_change = NaN(size(forecasts_CON,1),size(forecasts_CON,2));
for kk = 1+forecast_lag_CON:1:size(forecasts_CON,1)
    if date_CON(kk,3) == date_CON(kk-forecast_lag_CON,3)
        forecasts_CON_change(kk,:)         = forecasts_CON(kk,:)-forecasts_CON(kk-forecast_lag_CON,:);
    elseif date_CON(kk,3)-1 == date_CON(kk-forecast_lag_CON,3)
        forecasts_CON_change(kk,1:end-1)   = forecasts_CON(kk,1:end-1)-forecasts_CON(kk-forecast_lag_CON,2:end);
    end
end

% Adjust February Consensus forecast changes
for kk = 1+forecast_lag_CON:1:size(forecasts_CON,1)
    if date_CON(kk,1)==2
        forecasts_CON_change(kk,:) = forecasts_CON(kk,:)-forecasts_CON(kk-1,:);
    end
end

% Extract chosen forecasts
forecasts_NB_new            = [];
forecasts_NB_new_change     = [];
forecasts_CON_new           = [];
forecasts_CON_new_change    = [];

% Inflation forecasts
forecasts_NB_new            = [forecasts_NB_new forecasts_NB(:,2:3)];
forecasts_NB_new_change     = [forecasts_NB_new_change forecasts_NB_change(:,2:3)];
forecasts_CON_new           = [forecasts_CON_new forecasts_CON(:,2:3)];
forecasts_CON_new_change    = [forecasts_CON_new_change forecasts_CON_change(:,2:3)];

% Output forecasts
forecasts_NB_new            = [forecasts_NB_new forecasts_NB(:,8:9)];
forecasts_NB_new_change     = [forecasts_NB_new_change forecasts_NB_change(:,8:9)];
forecasts_CON_new           = [forecasts_CON_new forecasts_CON(:,8:9)];
forecasts_CON_new_change    = [forecasts_CON_new_change forecasts_CON_change(:,8:9)];
forecasts_NB_match_MP       = [forecasts_NB_new forecasts_NB_new_change];
forecasts_CON_match_MP      = [forecasts_CON_new forecasts_CON_new_change];

forecasts_MP                = NaN(size(date_MP,1),size(forecasts_NB_match_MP,2));

%% Forecast Allocation by Type of Forecast

count_assignment = zeros(size(forecasts_MP,1),7,3);

% Norges Bank Forecasts
for jj = 1:size(forecasts_MP,1)
    for kk = 1:size(forecasts_NB_match_MP,1)
        if isnan(forecasts_MP(jj,1)) == 1
            if max(isnan(forecasts_NB_match_MP(kk,:)))~=1
                if include_NB >= 0 && date_MP(jj,1) == date_NB(kk,1) && date_MP(jj,2) == date_NB(kk,2) && date_MP(jj,3) == date_NB(kk,3)

                    forecasts_MP(jj,:)          = forecasts_NB_match_MP(kk,:);
                    count_assignment(jj,1,1)    = count_assignment(jj,1,1) + 1;

                elseif include_NB >= 1 && date_MP(jj,1) == date_NB(kk,1) && date_MP(jj,2) > date_NB(kk,2) && date_MP(jj,3) == date_NB(kk,3)

                    forecasts_MP(jj,:)          = forecasts_NB_match_MP(kk,:);
                    count_assignment(jj,2,1)    = count_assignment(jj,2,1) + 1;

                elseif include_NB >= 2 && ...
                   ((date_MP(jj,1)-1 == date_NB(kk,1) && date_MP(jj,3) == date_NB(kk,3)) || ...
                    (date_MP(jj,1) == 1 && date_NB(kk,1) == 12 && date_MP(jj,3)-1 == date_NB(kk,3)))

                    forecasts_MP(jj,:)          = forecasts_NB_match_MP(kk,:);
                    count_assignment(jj,3,1)    = count_assignment(jj,3,1) + 1;

                elseif include_NB >= 3 && ...
                   ((date_MP(jj,1)-2 == date_NB(kk,1) && date_MP(jj,3) == date_NB(kk,3)) || ...
                   (date_MP(jj,1) == 2 && date_NB(kk,1) == 12 && date_MP(jj,3)-1 == date_NB(kk,3)) || ...
                   (date_MP(jj,1) == 1 && date_NB(kk,1) == 11 && date_MP(jj,3)-1 == date_NB(kk,3)))

                    forecasts_MP(jj,:)          = forecasts_NB_match_MP(kk,:);
                    count_assignment(jj,4,1)    = count_assignment(jj,4,1) + 1;

                elseif include_NB >= 4 && ...
                   ((date_MP(jj,1)-3 == date_NB(kk,1) && date_MP(jj,3) == date_NB(kk,3)) || ...
                   (date_MP(jj,1) == 3 && date_NB(kk,1) == 12 && date_MP(jj,3)-1 == date_NB(kk,3)) || ...
                   (date_MP(jj,1) == 2 && date_NB(kk,1) == 11 && date_MP(jj,3)-1 == date_NB(kk,3)) || ...
                   (date_MP(jj,1) == 1 && date_NB(kk,1) == 10 && date_MP(jj,3)-1 == date_NB(kk,3)))

                    forecasts_MP(jj,:)          = forecasts_NB_match_MP(kk,:);
                    count_assignment(jj,5,1)    = count_assignment(jj,5,1) + 1;

                elseif include_NB >= 5 && ...
                   ((date_MP(jj,1)-4 == date_NB(kk,1) && date_MP(jj,3) == date_NB(kk,3)) || ...
                   (date_MP(jj,1) == 4 && date_NB(kk,1) == 12 && date_MP(jj,3)-1 == date_NB(kk,3)) || ...
                   (date_MP(jj,1) == 3 && date_NB(kk,1) == 11 && date_MP(jj,3)-1 == date_NB(kk,3)) || ...
                   (date_MP(jj,1) == 2 && date_NB(kk,1) == 10 && date_MP(jj,3)-1 == date_NB(kk,3)) || ...
                   (date_MP(jj,1) == 1 && date_NB(kk,1) == 9  && date_MP(jj,3)-1 == date_NB(kk,3)))

                    forecasts_MP(jj,:)          = forecasts_NB_match_MP(kk,:);
                    count_assignment(jj,6,1)    = count_assignment(jj,6,1) + 1;

                end
            end
        end
    end
end

% Consensus Forecasts
if include_consensus~=0
    for jj = 1:size(forecasts_MP,1)
        for kk = 1:size(forecasts_CON_match_MP,1)
            if isnan(forecasts_MP(jj,1)) == 1
                if max(isnan(forecasts_CON_match_MP(kk,:)))~=1
                    if date_MP(jj,1) == date_CON(kk,1) && date_MP(jj,2) > date_CON(kk,2) && date_MP(jj,3) == date_CON(kk,3)

                        forecasts_MP(jj,:)          = forecasts_CON_match_MP(kk,:);
                        count_assignment(jj,1,3)    = count_assignment(jj,1,3) + 1;

                    elseif include_consensus >= 2 && ...
                        ((date_MP(jj,1)-1 == date_CON(kk,1) && date_MP(jj,3) == date_CON(kk,3)) || ...
                        (date_MP(jj,1) == 1 && date_CON(kk,1) == 12 && date_MP(jj,3)-1 == date_CON(kk,3)))

                        forecasts_MP(jj,:)          = forecasts_CON_match_MP(kk,:);
                        count_assignment(jj,2,3)    = count_assignment(jj,2,3) + 1;

                    elseif include_consensus >= 3 && ...
                       ((date_MP(jj,1)-2 == date_CON(kk,1) && date_MP(jj,3) == date_CON(kk,3)) || ...
                       (date_MP(jj,1) == 2 && date_CON(kk,1) == 12 && date_MP(jj,3)-1 == date_CON(kk,3)) || ...
                       (date_MP(jj,1) == 1 && date_CON(kk,1) == 11 && date_MP(jj,3)-1 == date_CON(kk,3)))

                        forecasts_MP(jj,:)          = forecasts_CON_match_MP(kk,:);
                        count_assignment(jj,3,3)    = count_assignment(jj,3,3) + 1;

                    elseif include_consensus >= 4 && ...
                       ((date_MP(jj,1)-3 == date_CON(kk,1) && date_MP(jj,3) == date_CON(kk,3)) || ...
                       (date_MP(jj,1) == 3 && date_CON(kk,1) == 12 && date_MP(jj,3)-1 == date_CON(kk,3)) || ...
                       (date_MP(jj,1) == 2 && date_CON(kk,1) == 11 && date_MP(jj,3)-1 == date_CON(kk,3)) || ...
                       (date_MP(jj,1) == 1 && date_CON(kk,1) == 10 && date_MP(jj,3)-1 == date_CON(kk,3)))

                        forecasts_MP(jj,:)          = forecasts_CON_match_MP(kk,:);
                        count_assignment(jj,4,3)    = count_assignment(jj,4,3) + 1;

                    end
                end
            end
        end
    end
end

%% Derive MP Shocks

% Restrict sample
rate_change_MP_y        = NaN(size(rate_change_MP,1),1);
count_assignment_y      = zeros(size(count_assignment,1),size(count_assignment,2),size(count_assignment,3));

for jj = 1:size(rate_change_MP_y,1)
    if date_MP(jj,3)>start_year_MP && date_MP(jj,3)<end_year_MP && isnan(rate_change_MP(jj,1)) == 0
        rate_change_MP_y(jj,1)      = rate_change_MP(jj,1);
        count_assignment_y(jj,:,:)  = count_assignment(jj,:,:);
    elseif date_MP(jj,3)==start_year_MP && date_MP(jj,1)>=start_month_MP && isnan(rate_change_MP(jj,1)) == 0
        rate_change_MP_y(jj,1)      = rate_change_MP(jj,1);
        count_assignment_y(jj,:,:)  = count_assignment(jj,:,:);
    elseif date_MP(jj,3)==end_year_MP && date_MP(jj,1)<=end_month_MP && isnan(rate_change_MP(jj,1)) == 0
        rate_change_MP_y(jj,1)      = rate_change_MP(jj,1);
        count_assignment_y(jj,:,:)  = count_assignment(jj,:,:);
    end
end

XX = [];

% Include Lagged Rate
rate_MP_lag = [NaN;rate_MP(1:end-1,1)];
XX          = [XX rate_MP_lag];

% Include Forecasts and Forecast Changes
XX = [XX forecasts_MP];

% Interaction Pre-Inflation Target
dummy_preinfltarget = date_MP(:,3)<2001 + (date_MP(:,3)==2001 & date_MP(:,1)<3);

% Include Exchange Rate
XX_exchange_rate = [exchange_rate_MP dummy_preinfltarget.*exchange_rate_MP];
XX               = [XX XX_exchange_rate];

% Run regression for first step policy rule
whichstats  = {'tstat','r','rsquare','adjrsquare'};
st          = regstats(rate_change_MP_y,XX,'linear',whichstats);
MP_shocks   = st.r;

% Show estimation results for first-step policy rule
First_Nb_meetings               = size(MP_shocks,1)-sum(isnan(MP_shocks))
First_Rsq                       = st.rsquare
First_AdjRsq                    = st.adjrsquare
First_MedianShockSize           = nanmedian(abs(MP_shocks))       
Nbf = 2; % Number of forecasts per type (e.g. infl., infl. changes, output, etc.)
First_beta_const                = [st.tstat.beta(1),st.tstat.pval(1)] 
First_beta_lagrate              = [st.tstat.beta(2),st.tstat.pval(2)] 
First_beta_infl                 = [st.tstat.beta(3:4)',st.tstat.pval(3:4)']
First_beta_infl_change          = [st.tstat.beta(5:6)',st.tstat.pval(5:6)']      
First_beta_output               = [st.tstat.beta(7:8)',st.tstat.pval(7:8)']
First_beta_output_change        = [st.tstat.beta(9:10)',st.tstat.pval(9:10)']
First_beta_realisedexch         = [st.tstat.beta(end-1),st.tstat.pval(end-1)']
First_beta_realisedexchinteract = [st.tstat.beta(end),st.tstat.pval(end)']

count_forecast = zeros(size(count_assignment,2),size(count_assignment,3));

for jj = 1:3
    for kk = 1:7
        count_forecast(kk,jj) = sum(count_assignment_y(:,kk,jj));
    end
end

elseif load_shocks_directly == 1
    
    cd '..\MP Shocks'
    
    date_MP     = xlsread('MP_Shocks.xlsx','Meeting-by-Meeting','A3:D180');
    MP_shocks   = date_MP(:,4);
    date_MP     = date_MP(:,1:3);
    
    rate_change_MP_y        = NaN(size(rate_change_MP,1),1);
    for jj = 1:size(rate_change_MP_y,1)
        if date_MP(jj,3)>start_year_MP && date_MP(jj,3)<end_year_MP && isnan(rate_change_MP(jj,1)) == 0
            rate_change_MP_y(jj,1)      = rate_change_MP(jj,1);
        elseif date_MP(jj,3)==start_year_MP && date_MP(jj,1)>=start_month_MP && isnan(rate_change_MP(jj,1)) == 0
            rate_change_MP_y(jj,1)      = rate_change_MP(jj,1);
        elseif date_MP(jj,3)==end_year_MP && date_MP(jj,1)<=end_month_MP && isnan(rate_change_MP(jj,1)) == 0
            rate_change_MP_y(jj,1)      = rate_change_MP(jj,1);
        end
    end
    
end

%% Convert MP shocks to monthly, quarterly, and annual series

% Add quarters to MP decisions
quarter_MP  = zeros(size(date_MP,1),1);
for jj = 1:size(quarter_MP,1)
    if date_MP(jj,1) == 1 || date_MP(jj,1) == 2 || date_MP(jj,1) == 3
        quarter_MP(jj,1) = 1;
    elseif date_MP(jj,1) == 4 || date_MP(jj,1) == 5 || date_MP(jj,1) == 6
        quarter_MP(jj,1) = 2;
    elseif date_MP(jj,1) == 7 || date_MP(jj,1) == 8 || date_MP(jj,1) == 9
        quarter_MP(jj,1) = 3;
    elseif date_MP(jj,1) == 10 || date_MP(jj,1) == 11 || date_MP(jj,1) == 12
        quarter_MP(jj,1) = 4;
    end
end

% Convert meeting shocks into monthly series
MP_shocks_month         = zeros(size(date_MA_month,1),1);
MP_shocks_month_count   = zeros(12,1);
MP_shocks_month_sign    = zeros(size(date_MA_month,1),2);
MP_shocks_month_halfs   = zeros(size(date_MA_month,1),2);
rate_change_month       = zeros(size(date_MA_month,1),1);

for jj = 1:size(MP_shocks_month,1)
    for kk = 1:size(MP_shocks,1)
        if date_MP(kk,3) == date_MA_month(jj,1) && date_MP(kk,1) == date_MA_month(jj,2)
            if isnan(MP_shocks(kk,1))==0
                
                MP_shocks_month(jj,1)                        = MP_shocks_month(jj,1) + MP_shocks(kk,1);
                MP_shocks_month_count(date_MA_month(jj,2),1) = MP_shocks_month_count(date_MA_month(jj,2),1) + 1;
                
                if date_MP(kk,1)>=1 && date_MP(kk,1)<=6
                    MP_shocks_month_halfs(jj,1) = MP_shocks_month_halfs(jj,1) + MP_shocks(kk,1);
                elseif date_MP(kk,1)>=7 && date_MP(kk,1)<=12
                    MP_shocks_month_halfs(jj,2) = MP_shocks_month_halfs(jj,2) + MP_shocks(kk,1);
                end
                
                if MP_shocks(kk,1)>0
                    MP_shocks_month_sign(jj,1) = MP_shocks_month_sign(jj,1) + MP_shocks(kk,1);
                elseif MP_shocks(kk,1)<0
                    MP_shocks_month_sign(jj,2) = MP_shocks_month_sign(jj,2) + MP_shocks(kk,1);
                end
                
            end
            
            if isnan(rate_change_MP_y(kk,1))==0
                rate_change_month(jj,1) = rate_change_month(jj,1) + rate_change_MP_y(kk,1);
            end
        end
    end
end

% Convert meeting shocks into quarterly series
MP_shocks_quart         = zeros(size(date_MA_quart,1),1);
MP_shocks_quart_halfs   = zeros(size(date_MA_quart,1),2);
MP_shocks_quart_sign    = zeros(size(date_MA_quart,1),2);
rate_change_quart       = zeros(size(date_MA_quart,1),1);

for jj = 1:size(MP_shocks_quart,1)
    for kk = 1:size(MP_shocks,1)
        if date_MP(kk,3) == date_MA_quart(jj,1) && quarter_MP(kk,1) == date_MA_quart(jj,2)
            if isnan(MP_shocks(kk,1))==0
                                
                MP_shocks_quart(jj,1) = MP_shocks_quart(jj,1) + MP_shocks(kk,1);
                
                if date_MP(kk,1)>=1 && date_MP(kk,1)<=6
                    MP_shocks_quart_halfs(jj,1) = MP_shocks_quart_halfs(jj,1) + MP_shocks(kk,1);
                elseif date_MP(kk,1)>=7 && date_MP(kk,1)<=12
                    MP_shocks_quart_halfs(jj,2) = MP_shocks_quart_halfs(jj,2) + MP_shocks(kk,1);
                end
                
                if MP_shocks(kk,1)>0
                    MP_shocks_quart_sign(jj,1) = MP_shocks_quart_sign(jj,1) + MP_shocks(kk,1);
                elseif MP_shocks(kk,1)<0
                    MP_shocks_quart_sign(jj,2) = MP_shocks_quart_sign(jj,2) + MP_shocks(kk,1);
                end

            end
            
            if isnan(rate_change_MP_y(kk,1))==0
                rate_change_quart(jj,1) = rate_change_quart(jj,1) + rate_change_MP_y(kk,1);
            end
        end
    end
end

% Convert meeting shocks into annual series
MP_shocks_annual        = zeros(size(date_MA_annual,1),1);
MP_shocks_annual_halfs  = zeros(size(date_MA_annual,1),2);
MP_shocks_annual_sign   = zeros(size(date_MA_annual,1),2);
rate_change_annual      = zeros(size(date_MA_annual,1),1);

for jj = 1:size(MP_shocks_annual,1)
    for kk = 1:size(MP_shocks,1)
        if date_MP(kk,3) == date_MA_annual(jj,1)
            if isnan(MP_shocks(kk,1))==0
                
                MP_shocks_annual(jj,1) = MP_shocks_annual(jj,1) + MP_shocks(kk,1);
                
                if date_MP(kk,1)>=1 && date_MP(kk,1)<=6
                    MP_shocks_annual_halfs(jj,1) = MP_shocks_annual_halfs(jj,1) + MP_shocks(kk,1);
                elseif date_MP(kk,1)>=7 && date_MP(kk,1)<=12
                    MP_shocks_annual_halfs(jj,2) = MP_shocks_annual_halfs(jj,2) + MP_shocks(kk,1);
                end
                
                if MP_shocks(kk,1)>0
                    MP_shocks_annual_sign(jj,1) = MP_shocks_annual_sign(jj,1) + MP_shocks(kk,1);
                elseif MP_shocks(kk,1)<0
                    MP_shocks_annual_sign(jj,2) = MP_shocks_annual_sign(jj,2) + MP_shocks(kk,1);
                end
                
            end
            
            if isnan(rate_change_MP_y(kk,1))==0
                rate_change_annual(jj,1) = rate_change_annual(jj,1) + rate_change_MP_y(kk,1);
            end
        end
    end
end

%% Define percentage changes in macro variables (monthly, quarterly, annual)

% Percentage changes for monthly series
Y_change_month = NaN(size(MP_shocks_month,1),IRF_T_month,size(macro_data_month,2));
for mm = 1:size(Y_change_month,3)
    for jj = 2:size(Y_change_month,1)
        for kk = 1:IRF_T_month
            if jj<=size(Y_change_month,1)-kk+1

                if mm == ind_PR_month || mm == ind_UN_month % Policy Rate, Unemp
                    Y_change_month(jj,kk,mm) = macro_data_month(jj+kk-1,mm)-macro_data_month(jj-1,mm);
                else % Remaining Variables
                    Y_change_month(jj,kk,mm) = 100*(log(macro_data_month(jj+kk-1,mm))-log(macro_data_month(jj-1,mm)));
                end
                
            end
        end
    end
end

% Percentage changes for quarterly series
Y_change_quart = NaN(size(MP_shocks_quart,1),IRF_T_quart,size(macro_data_quart,2));
for mm = 1:size(Y_change_quart,3)
    for jj = 2:size(Y_change_quart,1)
        for kk = 1:IRF_T_quart
            if jj<=size(Y_change_quart,1)-kk+1
                
                if mm == ind_PR_quart || mm == ind_UN_quart % Policy Rate, Unemp
                	Y_change_quart(jj,kk,mm) = macro_data_quart(jj+kk-1,mm)-macro_data_quart(jj-1,mm);
                else % Remaining Variables
                	Y_change_quart(jj,kk,mm) = 100*(log(macro_data_quart(jj+kk-1,mm))-log(macro_data_quart(jj-1,mm)));
                end
                
            end
        end
    end
end

% Percentage changes for annual series
Y_change_annual = NaN(size(MP_shocks_annual,1),IRF_T_annual,size(macro_data_annual,2));
for mm = 1:size(Y_change_annual,3)
    for jj = 2:size(Y_change_annual,1)
        for kk = 1:IRF_T_annual
            if jj<=size(Y_change_annual,1)-kk+1
                
                if mm == ind_PR_annual || mm == ind_UN_annual || mm == ind_ineq1_annual || mm == ind_ineq2_annual || mm == ind_ineq3_annual % Unemp, Policy Rate, Inequality Measures
                    Y_change_annual(jj,kk,mm) = macro_data_annual(jj+kk-1,mm)-macro_data_annual(jj-1,mm);
                else % Remaining Variables
                    Y_change_annual(jj,kk,mm) = 100*(log(macro_data_annual(jj+kk-1,mm))-log(macro_data_annual(jj-1,mm)));
                end
                
            end
        end
    end
end

%% Create Seasonal Dummies

seasonal_dummy_quart = zeros(size(date_MA_quart,1),3);
seasonal_dummy_month = zeros(size(date_MA_month,1),11);

for jj = 1:size(seasonal_dummy_quart,1)
    for mm = 1:size(seasonal_dummy_quart,2)
        if date_MA_quart(jj,2) == mm
            seasonal_dummy_quart(jj,mm) = 1;
        end
    end
end

for jj = 1:size(seasonal_dummy_month,1)
    for mm = 1:size(seasonal_dummy_month,2)
        if date_MA_month(jj,2) == mm
            seasonal_dummy_month(jj,mm) = 1;
        end
    end
end

%% Check for Predictability of Shock Series

lags_predict    = 3; % Lag-length for predictability check
start_macro     = (start_year-1990)*12 + start_month;
end_macro       = (end_year-1990)*12 + end_month;

controls_predict = NaN(size(date_MA_month,1),3*lags_predict);
for mm = 1:size(Y_change_month,3)
    if mm == ind_UN_month
        for jj = 1:lags_predict
            controls_predict(:,jj) = [NaN(jj,1);Y_change_month(1:end-jj,1,mm)];
        end
    elseif mm == ind_CPIAEL_month
        for jj = 1:lags_predict
            controls_predict(:,jj+lags_predict) = [NaN(jj,1);Y_change_month(1:end-jj,1,mm)];
        end
    elseif mm == ind_IP_month
        for jj = 1:lags_predict
            controls_predict(:,jj+2*lags_predict) = [NaN(jj,1);Y_change_month(1:end-jj,1,mm)];
        end
    end
end

F_test_predict  = zeros(4,2);
whichstats      = {'tstat','fstat'};
YY              = MP_shocks_month(start_macro:end_macro,1);

XX                  = controls_predict(start_macro:end_macro,1:lags_predict);
st                  = regstats(YY,XX,'linear',whichstats);
F_test_predict(1,1) = st.fstat.f;
F_test_predict(1,2) = st.fstat.pval;
XX                  = controls_predict(start_macro:end_macro,lags_predict+1:2*lags_predict);
st                  = regstats(YY,XX,'linear',whichstats);
F_test_predict(2,1) = st.fstat.f;
F_test_predict(2,2) = st.fstat.pval;
XX                  = controls_predict(start_macro:end_macro,2*lags_predict+1:end);
st                  = regstats(YY,XX,'linear',whichstats);
F_test_predict(3,1) = st.fstat.f;
F_test_predict(3,2) = st.fstat.pval;
XX                  = controls_predict(start_macro:end_macro,:);
st                  = regstats(YY,XX,'linear',whichstats);
F_test_predict(4,1) = st.fstat.f;
F_test_predict(4,2) = st.fstat.pval;

%% Run Local Projections for monthly series

beta_month  = zeros(IRF_T_month,5*size(Y_change_month,3));
start_macro = (start_year-1990)*12 + start_month;
end_macro   = (end_year-1990)*12 + end_month;

% Controlling for lags of dependent variable
controls_month_var = NaN(size(date_MA_month,1),lags_month_var,size(Y_change_month,3));
for mm = 1:size(Y_change_month,3)
    for jj = 1:lags_month_var
        controls_month_var(:,jj,mm) = [NaN(jj,1);Y_change_month(1:end-jj,1,mm)];            
    end
end

% Controlling for lags of the shock
controls_month_shock = NaN(size(date_MA_month,1),lags_month_shock);
for jj = 1:lags_month_shock
    controls_month_shock(:,jj)      = [NaN(jj,1);MP_shocks_month(1:end-jj,1)];
end

% Controls for lagged rate
controls_month_rate = NaN(size(date_MA_month,1),lags_month_shock);
for jj = 1:lags_month_shock
    controls_month_rate(:,jj) = [NaN(jj,1);rate_change_month(1:end-jj,1)];
end

for mm = 1:size(Y_change_month,3)

    % MP-shocks or regressor rate change + controls for each
    if regressor_rate_change == 1
        XX = [rate_change_month controls_month_rate];
    else
        XX = [MP_shocks_month controls_month_shock];
    end
    
    % Include Seasonal Dummies
    if mm == ind_CPIAEL_month || mm == ind_PPI_month
        XX = [XX seasonal_dummy_month];
    end
    
    % Include IP Dummy
    if mm == ind_IP_month
        XX = [XX dummy_IP_month];
    end
    
    % Include Controls for Dependent Variable
    XX = [XX controls_month_var(:,:,mm)];
    
    % Exclude all controls for selected variables
    if mm == ind_PR_month
        if regressor_rate_change == 1
            XX = rate_change_month;
        else
            XX = MP_shocks_month(:,1);
        end
    end
    
    % Restrict Sample
    XX = XX(start_macro:end_macro,:);
    % Exclude Columns with NaNs
    NaN_columns         = find(all(isnan(XX)));
    XX(:,NaN_columns)   = [];

    for jj = 1:IRF_T_month

        YY  = Y_change_month(start_macro:end_macro,jj,mm);

        maxLag                      = floor(4*(size(XX,1)/100)^(2/9));
        [EstCov,hac_se,hac_coeff]   = hac(XX,YY,'bandwidth',maxLag+1,'display','off');
        est_beta                    = hac_coeff(2,1);
        est_se                      = hac_se(2,1);

        beta_month(jj,1+(mm-1)*5)   = est_beta;
        beta_month(jj,2+(mm-1)*5)   = est_beta-tinv(0.975,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_month(jj,3+(mm-1)*5)   = est_beta-tinv(0.84,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_month(jj,4+(mm-1)*5)   = est_beta+tinv(0.84,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_month(jj,5+(mm-1)*5)   = est_beta+tinv(0.975,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;

    end
end

% Policy rate responses to MP Tightenings & Easings
beta_month_sign = zeros(IRF_T_month,5*3);

for mm = 1:3

    if mm == 1
        XX = MP_shocks_month;
    elseif mm == 2
        XX = MP_shocks_month_sign(:,1);
    elseif mm == 3
        XX = MP_shocks_month_sign(:,2);
    end
    
    % Restrict Sample
    XX = XX(start_macro:end_macro,:);
    % Exclude Columns with NaNs
    NaN_columns         = find(all(isnan(XX)));
    XX(:,NaN_columns)   = [];

    for jj = 1:IRF_T_month

        YY  = Y_change_month(start_macro:end_macro,jj,ind_PR_month);

        maxLag                      = floor(4*(size(XX,1)/100)^(2/9));
        [EstCov,hac_se,hac_coeff]   = hac(XX,YY,'bandwidth',maxLag+1,'display','off');
        est_beta                    = hac_coeff(2,1);
        est_se                      = hac_se(2,1);

        beta_month_sign(jj,1+(mm-1)*5)   = est_beta;
        beta_month_sign(jj,2+(mm-1)*5)   = est_beta-tinv(0.975,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_month_sign(jj,3+(mm-1)*5)   = est_beta-tinv(0.84,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_month_sign(jj,4+(mm-1)*5)   = est_beta+tinv(0.84,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_month_sign(jj,5+(mm-1)*5)   = est_beta+tinv(0.975,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;

    end
end

% IRFs to first and second halfs shocks
beta_month_halfs = zeros(IRF_T_month,4,2);

controls_month_shock = NaN(size(date_MA_month,1),lags_month_shock,2);

for jj = 1:lags_month_shock
    controls_month_shock(:,jj,1)    = [NaN(jj,1);MP_shocks_month_halfs(1:end-jj,1)];
    controls_month_shock(:,jj,2)    = [NaN(jj,1);MP_shocks_month_halfs(1:end-jj,2)];
end

for mm = 1:4
    for kk = 1:2

        if kk == 1
            XX = [MP_shocks_month_halfs(:,1) controls_month_shock(:,:,1)]; %  controls_month_shock(:,:,2)
        elseif kk == 2
            XX = [MP_shocks_month_halfs(:,2) controls_month_shock(:,:,2)]; %  controls_month_shock(:,:,1) MP_shocks_month_halfs(:,1)
        end

        % Restrict Sample
        XX = XX(start_macro:end_macro,:);
        % Exclude Columns with NaNs
        NaN_columns         = find(all(isnan(XX)));
        XX(:,NaN_columns)   = [];

        for jj = 1:IRF_T_month

            YY  = Y_change_month(start_macro:end_macro,jj,mm);

            maxLag                      = floor(4*(size(XX,1)/100)^(2/9));
            [EstCov,hac_se,hac_coeff]   = hac(XX,YY,'bandwidth',maxLag+1,'display','off');
            est_beta                    = hac_coeff(2,1);
            est_se                      = hac_se(2,1);
            beta_month_halfs(jj,mm,kk)  = est_beta;

        end
        
    end
end

%% Run Local Projections for quarterly series

beta_quart      = zeros(IRF_T_quart,5*size(Y_change_quart,3));
start_macro     = (start_year-1990)*4 + start_quarter;
end_macro       = (end_year-1990)*4 + end_quarter;

% Controlling for lags of dependent variable
controls_quart_var  = NaN(size(date_MA_quart,1),lags_quart_var,size(Y_change_quart,3));
for mm = 1:size(Y_change_quart,3)
    for jj = 1:lags_quart_var
        controls_quart_var(:,jj,mm) = [NaN(jj,1);Y_change_quart(1:end-jj,1,mm)];
    end
end

% Controlling for lags of the shock
controls_quart_shock = NaN(size(date_MA_quart,1),lags_quart_shock);
for jj = 1:lags_quart_shock
    controls_quart_shock(:,jj)      = [NaN(jj,1);MP_shocks_quart(1:end-jj,1)];
end

% Controls for lagged rate
controls_quart_rate = NaN(size(date_MA_quart,1),lags_quart_shock);
for jj = 1:lags_quart_shock
    controls_quart_rate(:,jj) = [NaN(jj,1);rate_change_quart(1:end-jj,1)];
end

for mm = 1:size(Y_change_quart,3)
    
    % MP-shocks or regressor rate change + controls for each
    if regressor_rate_change == 1
        XX = [rate_change_quart controls_quart_rate];
    else
        XX = [MP_shocks_quart controls_quart_shock];
    end

    % Include Seasonal Dummies
    if mm == ind_CPIAEL_quart || mm == ind_HP_quart
        XX = [XX seasonal_dummy_quart];
    end
    
    % Include IP Dummy
    if mm == ind_IP_quart
        XX = [XX dummy_IP_quart];
    end
    
    % Include Controls for Dependent Variable
    XX = [XX controls_quart_var(:,:,mm)];
    
    % Exclude all controls for selected variables
    if mm == ind_PR_quart
        if regressor_rate_change == 1
            XX = rate_change_quart;
        else
            XX = MP_shocks_quart(:,1);
        end
    end
    
    % Restrict Sample
    XX = XX(start_macro:end_macro,:);
    % Exclude columns with NaNs
    NaN_columns         = find(all(isnan(XX)));
    XX(:,NaN_columns)   = [];

    for jj = 1:IRF_T_quart

        YY = Y_change_quart(start_macro:end_macro,jj,mm);
        
        maxLag                      = floor(4*(size(XX,1)/100)^(2/9));
        [EstCov,hac_se,hac_coeff]   = hac(XX,YY,'bandwidth',maxLag+1,'display','off');
        est_beta                    = hac_coeff(2,1);
        est_se                      = hac_se(2,1);

        beta_quart(jj,1+(mm-1)*5)   = est_beta;
        beta_quart(jj,2+(mm-1)*5)   = est_beta-tinv(0.975,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_quart(jj,3+(mm-1)*5)   = est_beta-tinv(0.84,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_quart(jj,4+(mm-1)*5)   = est_beta+tinv(0.84,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_quart(jj,5+(mm-1)*5)   = est_beta+tinv(0.975,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;

    end
end

%% Run Local Projections for annual series

beta_annual         = zeros(IRF_T_annual,5*size(Y_change_annual,3));
start_macro         = start_year-1989;
end_macro           = end_year-1989;

% Controlling for lags of dependent variable
controls_annual_var  = NaN(size(date_MA_annual,1),lags_annual_var,size(Y_change_annual,3));
for mm = 1:size(Y_change_annual,3)
    for jj = 1:lags_annual_var
        controls_annual_var(:,jj,mm) = [NaN(jj,1);Y_change_annual(1:end-jj,1,mm)];
    end
end

% Controlling for lags of the shock
controls_annual_shock = NaN(size(date_MA_annual,1),lags_annual_shock);
for jj = 1:lags_annual_shock
    controls_annual_shock(:,jj)      = [NaN(jj,1);MP_shocks_annual(1:end-jj,1)];
end

% Controls for lagged rate
controls_annual_rate = NaN(size(date_MA_annual,1),lags_annual_shock);
for jj = 1:lags_annual_shock
    controls_annual_rate(:,jj) = [NaN(jj,1);rate_change_annual(1:end-jj,1)];
end

for mm = 1:size(Y_change_annual,3)

    % MP-shocks or regressor rate change + controls for each        
    if regressor_rate_change == 1
        XX = [rate_change_annual controls_annual_rate];
    else
        XX = [MP_shocks_annual controls_annual_shock];
    end
    
    % Include Dummy for IP        
    if mm == ind_IP_annual
        XX = [XX dummy_IP_annual];
    end
    
    % Include Controls for Dependent Variable
    XX = [XX controls_annual_var(:,:,mm)];
    
    % Exclude all controls for selected variables
    if mm == ind_PR_annual
        if regressor_rate_change == 1
            XX = rate_change_annual;
        else
            XX = MP_shocks_annual(:,1);
        end
    end
    
    % Restrict Sample
    XX = XX(start_macro:end_macro,:);
    % Exclude Columns with NaNs
    NaN_columns         = find(all(isnan(XX)));
    XX(:,NaN_columns)   = [];

    for jj = 1:IRF_T_annual

        YY = Y_change_annual(start_macro:end_macro,jj,mm);
        
        maxLag                       = floor(4*(size(XX,1)/100)^(2/9));
        [EstCov,hac_se,hac_coeff]    = hac(XX,YY,'bandwidth',maxLag+1,'display','off');
        est_beta                     = hac_coeff(2,1);
        est_se                       = hac_se(2,1);

        beta_annual(jj,1+(mm-1)*5)   = est_beta;
        beta_annual(jj,2+(mm-1)*5)   = est_beta-tinv(0.975,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_annual(jj,3+(mm-1)*5)   = est_beta-tinv(0.84,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_annual(jj,4+(mm-1)*5)   = est_beta+tinv(0.84,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;
        beta_annual(jj,5+(mm-1)*5)   = est_beta+tinv(0.975,size(YY,1)-sum(isnan(YY))-size(XX,2)-1)*est_se;

    end
end

%% Figures: Impulse responses LP monthly

cd '..\..\Matlab'

if run_main_IRFs == 1

zero_line = zeros(size(beta_month,1),1);

figure
for mm = 1:4
    subplot(2,2,mm)
    hold on;
    plot(beta_month(:,1+(mm-1)*5),'b','Linewidth',3,'Color',rgb('Mediumblue'))
    plot(beta_month(:,2+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_month(:,3+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_month(:,4+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_month(:,5+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    ciplot(beta_month(:,3+(mm-1)*5),beta_month(:,4+(mm-1)*5));
    ciplot(beta_month(:,2+(mm-1)*5),beta_month(:,5+(mm-1)*5));
    plot(zero_line,'black')
    hold off;
    axis tight
    t = title(labels_month(1,mm));
    set(gca,'Box','on','FontSize',20)
    xlim([1 size(beta_month,1)])
    xticks(1:12:size(beta_month,1))
    xticklabels({'0','12','24','36','48','60'})
    if y_labels_month(1,mm) == 1
        ylabel('Percentage Points','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    else
        ylabel('Percent','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    end
    xlabel('Month','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    set(t,'fontsize',26,'FontName','Palatino','Interpreter','Latex')
    grid on
    set(gca,'GridLineStyle','--')
    ax = gca;
    ax.GridAlpha = .5;
end
h = gcf;
set(h,'PaperPositionMode','auto')
set(h,'PaperOrientation','landscape')
set(h,'Position',[0 0 1400 1000])
tightfig;
print(h,'-depsc','..\Figures\Macro\FIG2_IRFs_LP_month_main')

figure
for mm = 5:size(Y_change_month,3)
    subplot(2,2,mm-4)
    hold on;
    plot(beta_month(:,1+(mm-1)*5),'b','Linewidth',3,'Color',rgb('Mediumblue'))
    plot(beta_month(:,2+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_month(:,3+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_month(:,4+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_month(:,5+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    ciplot(beta_month(:,3+(mm-1)*5),beta_month(:,4+(mm-1)*5));
    ciplot(beta_month(:,2+(mm-1)*5),beta_month(:,5+(mm-1)*5));
    plot(zero_line,'black')
    hold on;
    axis tight
    t = title(labels_month(1,mm));
    set(gca,'Box','on','FontSize',20)
    xlim([1 size(beta_month,1)])
    xticks(1:12:size(beta_month,1))
    xticklabels({'0','12','24','36','48','60'})
    if y_labels_month(1,mm) == 1
        ylabel('Percentage Points','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    else
        ylabel('Percent','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    end
    xlabel('Month','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    set(t,'fontsize',24,'FontName','Palatino','Interpreter','Latex')
    grid on
    set(gca,'GridLineStyle','--')
    ax = gca;
    ax.GridAlpha = .5;
end
h = gcf;
set(h, 'PaperPositionMode','auto')
set(h,'PaperOrientation','landscape')
set(h,'Position',[0 0 1400 1000])
tightfig;
print(h,'-depsc','..\Figures\Macro\FIGA7_IRFs_LP_month_add')

end

%% Figures: Impulse responses LP quarterly

zero_line = zeros(size(beta_quart,1),1);

if run_main_IRFs == 1

figure
for mm = 1:6
    subplot(2,3,mm)
    hold on;
    plot(beta_quart(:,1+(mm-1)*5),'b','Linewidth',3,'Color',rgb('Mediumblue'))
    plot(beta_quart(:,2+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_quart(:,3+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_quart(:,4+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_quart(:,5+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    ciplot(beta_quart(:,3+(mm-1)*5),beta_quart(:,4+(mm-1)*5));
    ciplot(beta_quart(:,2+(mm-1)*5),beta_quart(:,5+(mm-1)*5));
    plot(zero_line,'black')
    hold off;
    axis tight
    t = title(labels_quart(1,mm));
    set(gca,'Box','on','FontSize',20)
    xlim([1 size(beta_quart,1)])
    xticks(1:4:size(beta_quart,1))
    xticklabels({'0','4','8','12','16','20'})
    if y_labels_quart(1,mm) == 1
        ylabel('Percentage Points','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    else
        ylabel('Percent','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    end
    xlabel('Quarter','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    set(t,'fontsize',26,'FontName','Palatino','Interpreter','Latex')
    grid on
    set(gca,'GridLineStyle','--')
    ax = gca;
    ax.GridAlpha = .5;
end
h = gcf;
set(h,'PaperPositionMode','auto')
set(h,'PaperOrientation','landscape')
set(h,'Position',[0 0 1800 1000])
tightfig;
print(h,'-depsc','..\Figures\Macro\FIGA8_IRFs_LP_quart_main')

figure
for mm = 7:12
    subplot(2,3,mm-6)
    hold on;
    plot(beta_quart(:,1+(mm-1)*5),'b','Linewidth',3,'Color',rgb('Mediumblue'))
    plot(beta_quart(:,2+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_quart(:,3+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_quart(:,4+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_quart(:,5+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    ciplot(beta_quart(:,3+(mm-1)*5),beta_quart(:,4+(mm-1)*5));
    ciplot(beta_quart(:,2+(mm-1)*5),beta_quart(:,5+(mm-1)*5));
    plot(zero_line,'black')
    hold off;
    axis tight
    t = title(labels_quart(1,mm));
    set(gca,'Box','on','FontSize',20)
    xlim([1 size(beta_quart,1)])
    xticks(1:4:size(beta_quart,1))
    xticklabels({'0','4','8','12','16','20'})
    if y_labels_quart(1,mm) == 1
        ylabel('Percentage Points','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    else
        ylabel('Percent','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    end
    xlabel('Quarter','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    set(t,'fontsize',26,'FontName','Palatino','Interpreter','Latex')
    grid on
    set(gca,'GridLineStyle','--')
    ax = gca;
    ax.GridAlpha = .5;
end
h = gcf;
set(h,'PaperPositionMode','auto')
set(h,'PaperOrientation','landscape')
set(h,'Position',[0 0 1800 1000])
tightfig;
print(h,'-depsc','..\Figures\Macro\FIGA9_IRFs_LP_quart_add')

end

%% Figures: Impulse responses LP annually

zero_line = zeros(size(beta_annual,1),1);

if run_main_IRFs == 1

figure
for mm = 1:6
    subplot(2,3,mm)
    hold on;
    plot(beta_annual(:,1+(mm-1)*5),'b','Linewidth',3,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,2+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,3+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,4+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,5+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    ciplot(beta_annual(:,3+(mm-1)*5),beta_annual(:,4+(mm-1)*5));
    ciplot(beta_annual(:,2+(mm-1)*5),beta_annual(:,5+(mm-1)*5));
    plot(zero_line,'black')
    hold off;
    axis tight
    t = title(labels_annual(1,mm));
    set(gca,'Box','on','FontSize',20)
    xlim([1 size(beta_annual,1)])
    xticks(1:1:size(beta_annual,1))
    xticklabels({'0','1','2','3','4','5'})
    if y_labels_annual(1,mm) == 1
        ylabel('Percentage Points','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    else
        ylabel('Percent','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    end
    xlabel('Year','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    set(t,'fontsize',26,'FontName','Palatino','Interpreter','Latex')
    grid on
    set(gca,'GridLineStyle','--')
    ax = gca;
    ax.GridAlpha = .5;
end
h = gcf;
set(h, 'PaperPositionMode','auto')
set(h,'PaperOrientation','landscape')
set(h,'Position',[0 0 1800 1000])
tightfig;
print(h,'-depsc','..\Figures\Macro\FIG3_IRFs_LP_annual_main')

figure
for mm = 7:12
    subplot(2,3,mm-6)
    hold on;
    plot(beta_annual(:,1+(mm-1)*5),'b','Linewidth',3,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,2+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,3+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,4+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,5+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    ciplot(beta_annual(:,3+(mm-1)*5),beta_annual(:,4+(mm-1)*5));
    ciplot(beta_annual(:,2+(mm-1)*5),beta_annual(:,5+(mm-1)*5));
    plot(zero_line,'black')
    hold off;
    axis tight
    t = title(labels_annual(1,mm));
    set(gca,'Box','on','FontSize',20)
    xlim([1 size(beta_annual,1)])
    xticks(1:1:size(beta_annual,1))
    xticklabels({'0','1','2','3','4','5'})
    if y_labels_annual(1,mm) == 1
        ylabel('Percentage Points','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    else
        ylabel('Percent','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    end
    xlabel('Year','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    set(t,'fontsize',26,'FontName','Palatino','Interpreter','Latex')
    grid on
    set(gca,'GridLineStyle','--')
    ax = gca;
    ax.GridAlpha = .5;
end
h = gcf;
set(h, 'PaperPositionMode','auto')
set(h,'PaperOrientation','landscape')
set(h,'Position',[0 0 1800 1000])
tightfig;
print(h,'-depsc','..\Figures\Macro\FIGA10_IRFs_LP_annual_add')

figure
for mm = 13:16
    subplot(2,2,mm-12)
    hold on;
    plot(beta_annual(:,1+(mm-1)*5),'b','Linewidth',3,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,2+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,3+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,4+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    plot(beta_annual(:,5+(mm-1)*5),'b','Linewidth',1,'Color',rgb('Mediumblue'))
    ciplot(beta_annual(:,3+(mm-1)*5),beta_annual(:,4+(mm-1)*5));
    ciplot(beta_annual(:,2+(mm-1)*5),beta_annual(:,5+(mm-1)*5));
    plot(zero_line,'black')
    hold off;
    axis tight
    t = title(labels_annual(1,mm));
    set(gca,'Box','on','FontSize',20)
    xlim([1 size(beta_annual,1)])
    xticks(1:1:size(beta_annual,1))
    xticklabels({'0','1','2','3','4','5'})
    if y_labels_annual(1,mm) == 1
        ylabel('Percentage Points','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    else
        ylabel('Percent','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    end
    xlabel('Year','fontsize',18,'FontName','Palatino','Interpreter','Latex')
    set(t,'fontsize',26,'FontName','Palatino','Interpreter','Latex')
    grid on
    set(gca,'GridLineStyle','--')
    ax = gca;
    ax.GridAlpha = .5;
end
h = gcf;
set(h, 'PaperPositionMode','auto')
set(h,'PaperOrientation','landscape')
set(h,'Position',[0 0 1400 1000])
tightfig;
print(h,'-depsc','..\Figures\Macro\FIGA11_IRFs_LP_annual_ineq')

end

%% Figures: Descriptive

if run_descriptive_figures == 1

    start_macro         = (start_year-1990)*12 + start_month;
    end_macro           = (end_year-1990)*12 + end_month;
    MP_shocks_figure    = MP_shocks_month(start_macro:end_macro,1)*100;
    Rate_change_figure  = rate_change_month(start_macro:end_macro,1)*100;

    figure
    plot(MP_shocks_figure,'LineWidth',3,'Color',rgb('Mediumblue'))
    set(gca,'XTick',[13:60:size(MP_shocks_figure,1)])
    set(gca,'XTickLabel',['1995';'2000';'2005';'2010';'2015'])
    xlim([1 size(MP_shocks_figure,1)])
    set(gca,'Box','off')
    set(gca,'FontSize',28)
    ylabel('Basis Points','Fontsize',34,'FontName','Palatino','Interpreter','Latex')
    h = gcf;
    set(h, 'PaperPositionMode','auto')
    set(h,'PaperOrientation','landscape')
    set(h,'Position',[0 0 1800 1000])
    tightfig
    print(h,'-depsc','..\Figures\Macro\FIG1_MP_shocks_month')
    
    figure
    plot(MP_shocks_figure,'LineWidth',3,'Color',rgb('Mediumblue'))
    hold all
    plot(Rate_change_figure,'LineWidth',3,'Color',rgb('Crimson'))
    set(gca,'XTick',[13:60:size(MP_shocks_figure,1)])
    set(gca,'XTickLabel',['1995';'2000';'2005';'2010';'2015'])
    xlim([1 size(MP_shocks_figure,1)])
    ylim([-110 70])
    set(gca,'Box','off')
    set(gca,'FontSize',28)
    ylabel('Basis Points','Fontsize',34,'FontName','Palatino','Interpreter','Latex')
    legend('Monetary Policy Shocks','Policy Rate Changes')
    h = gcf;
    set(h, 'PaperPositionMode','auto')
    set(h,'PaperOrientation','landscape')
    set(h,'Position',[0 0 1800 1000])
    tightfig
    print(h,'-depsc','..\Figures\Macro\FIGA4_MP_shocks_rate_change_month')

    start_macro         = (start_year-1990)*4 + start_quarter;
    end_macro           = (end_year-1990)*4 + end_quarter;
    MP_shocks_figure    = MP_shocks_quart(start_macro:end_macro,1)*100;

    figure
    plot(MP_shocks_figure,'LineWidth',3,'Color',rgb('Mediumblue'))
    set(gca,'XTick',[5:20:size(MP_shocks_figure,1)])
    set(gca,'XTickLabel',['1995';'2000';'2005';'2010';'2015'])
    xlim([1 size(MP_shocks_figure,1)])
    set(gca,'Box','off')
    set(gca,'FontSize',28)
    ylabel('Basis Points','Fontsize',34,'FontName','Palatino','Interpreter','Latex')
    h = gcf;
    set(h, 'PaperPositionMode','auto')
    set(h,'PaperOrientation','landscape')
    set(h,'Position',[0 0 1800 1000])
    tightfig
    print(h,'-depsc','..\Figures\Macro\FIGA2_MP_shocks_quart')

    start_macro         = start_year-1989;
    end_macro           = end_year-1989;
    MP_shocks_figure    = MP_shocks_annual(start_macro:end_macro,1)*100;

    figure
    plot(MP_shocks_figure,'LineWidth',3,'Color',rgb('Mediumblue'))
    set(gca,'XTick',[2:5:size(MP_shocks_figure,1)])
    set(gca,'XTickLabel',['1995';'2000';'2005';'2010';'2015'])
    xlim([1 size(MP_shocks_figure,1)])
    set(gca,'Box','off')
    set(gca,'FontSize',28)
    ylabel('Basis Points','Fontsize',34,'FontName','Palatino','Interpreter','Latex')
    h = gcf;
    set(h, 'PaperPositionMode','auto')
    set(h,'PaperOrientation','landscape')
    set(h,'Position',[0 0 1800 1000])
    tightfig
    print(h,'-depsc','..\Figures\Macro\FIGA3_MP_shocks_annual')
    
    Policy_rate_annual  = macro_data_annual(start_macro:end_macro,1);
    Loan_rate_annual    = macro_data_annual(start_macro:end_macro,18);
    Deposit_rate_annual = macro_data_annual(start_macro:end_macro,19);
    
    figure
    hold on;
    plot(Loan_rate_annual,'LineWidth',4,'Color',rgb('Crimson'))
    plot(Deposit_rate_annual,'LineWidth',4,'Color',rgb('DarkCyan'))
    plot(Policy_rate_annual,'LineWidth',4,'Color',rgb('Mediumblue'))
    hold off;
    set(gca,'XTick',[2:5:size(MP_shocks_figure,1)])
    set(gca,'XTickLabel',['1995';'2000';'2005';'2010';'2015'])
    xlim([1 size(MP_shocks_figure,1)])
    set(gca,'Box','off')
    set(gca,'FontSize',28)
    ylabel('Percent','Fontsize',34,'FontName','Palatino','Interpreter','Latex')
    legend('Average Loan Rate','Average Deposit Rate','Policy Rate','Fontsize',34,'FontName','Palatino','Interpreter','Latex')
    h = gcf;
    set(h, 'PaperPositionMode','auto')
    set(h,'PaperOrientation','landscape')
    set(h,'Position',[0 0 1800 1000])
    tightfig
    print(h,'-depsc','..\Figures\Macro\FIGB1_Deposit_loan_rates')
        
end
